' UnionFind
'
import numpy as np

class UnionFind():

    def __init__(self, n):
        'Initializes the UnionFind object

        Args:
            n (int): The number of elements in the UnionFind.
        '
        self.n = n
        self.parents = ([(- 1)] * n)

    def find(self, x):
        'Finds the root of the tree that x is in

        Args:
            x (int): The element to find the root for.

        Returns:
            int: The root of the tree that x is in.
        '
        if (self.parents[x] < 0):
            return x
        else:
            self.parents[x] = self.find(self.parents[x])
            return self.parents[x]

    def union(self, x, y):
        'Unions two trees together

        Args:
            x (int): The first tree to union.
            y (int): The second tree to union.
        '
        x = self.find(x)
        y = self.find(y)
        if (x == y):
            return
        if (self.parents[x] > self.parents[y]):
            (x, y) = (y, x)
        self.parents[x] += self.parents[y]
        self.parents[y] = x

    def size(self, x):
        'Returns the size of the tree that x is in

        Args:
            x (int): The element to find the size for.

        Returns:
            int: The size of the tree that x is in.
        '
        return (- self.parents[self.find(x)])

    def same(self, x, y):
        'Returns whether or not x and y are in the same tree

        Args:
            x (int): The first element to check.
            y (int): The second element to check.

        Returns:
            bool: Whether or not x and y are in the same tree.
        '
        return (self.find(x) == self.find(y))

    def members(self, x):
        'Returns all of the members of the tree that x is in

        Args:
            x (int): The element to find the members for.

        Returns:
            list: All of the members of the tree that x is in.
        '
        root = self.find(x)
        return [i for i in range(self.n) if (self.find(i) == root)]

    def roots(self):
        'Returns all of the roots of the trees

        Returns:
            list: All of the roots of the trees.
        '
        return [i for (i, x) in enumerate(self.parents) if (x < 0)]

    def group_count(self):
        'Returns the number of groups

        Returns:
            int: The number of groups.
        '
        return len(self.roots())

    def all_group_members(self):
        'Returns all of the members of each group

        Returns:
            dict: All of the members of each group.
        '
        return {r: self.members(r) for r in self.roots()}

    def __str__(self):
        'Returns a string representation of the UnionFind

        Returns:
            str: A string representation of the UnionFind.
        '
        return '\n'.join(('{}: {}'.format(r, self.members(r)) for r in self.roots()))

