# File changed

import sys
import numpy as np
import numba
from numba import njit, b1, i4, i8, f8
read = sys.stdin.buffer.read
readline = sys.stdin.buffer.readline
readlines = sys.stdin.buffer.readlines

@njit(((numba.types.optional(i8[:]),) * 2), cache=True)
def seg_f(x, y):
    'Performs a segment operation

    Args:
        x (np.array): The first segment.
        y (np.array): The second segment.

    Returns:
        np.array: The result of the operation.
    '
    if (x is None):
        return y
    if (y is None):
        return x
    (a0, a1, ainv) = x
    (b0, b1, binv) = y
    (c0, c1, cinv) = ((a0 + b0), (a1 + b1), ((ainv + binv) + (a1 * b0)))
    return np.array([c0, c1, cinv], np.int64)

@njit((b1, b1), cache=True)
def lazy_f(a, b):
    'Performs a lazy operation

    Args:
        a (bool): The first value.
        b (bool): The second value.

    Returns:
        bool: The result of the operation.
    '
    return (a ^ b)

@njit((i8[:], b1), cache=True)
def operate_f(x, a):
    'Performs an operation on a segment

    Args:
        x (np.array): The segment to operate on.
        a (bool): The value to operate with.

    Returns:
        np.array: The result of the operation.
    '
    if (not a):
        return x
    (x0, x1, xinv) = x
    (x0, x1, xinv) = (x1, x0, ((x0 * x1) - xinv))
    return np.array([x0, x1, xinv], np.int64)

@njit((i8[:, :], b1[:], i8), cache=True)
def _eval_at(seg, lazy, i):
    'Evaluates a segment at a given index

    Args:
        seg (np.array): The segment to evaluate.
        lazy (np.array): The lazy array.
        i (int): The index to evaluate at.

    Returns:
        np.array: The result of the evaluation.
    '
    return operate_f(seg[i], lazy[i])

@njit((i8[:, :], b1[:], i8), cache=True)
def _propagate_at(seg, lazy, i):
    'Propagates a segment at a given index

    Args:
        seg (np.array): The segment to propagate.
        lazy (np.array): The lazy array.
        i (int): The index to propagate at.
    '
    seg[i] = _eval_at(seg, lazy, i)
    lazy[(i << 1)] = lazy_f(lazy[(i << 1)], lazy[i])
    lazy[((i << 1) | 1)] = lazy_f(lazy[((i << 1) | 1)], lazy[i])
    lazy[i] = 0

@njit((i8[:, :],), cache=True)
def build(raw_data):
    'Builds a segment tree

    Args:
        raw_data (np.array): The raw data to build the segment tree from.

    Returns:
        np.array: The segment tree.
    '
    N = len(raw_data)
    seg = np.empty(((N + N), 3), np.int64)
    seg[N:] = raw_data
    for i in range((N - 1), 0, (- 1)):
        seg[i] = seg_f(seg[(i << 1)], seg[((i << 1) | 1)])
    return seg

@njit((i8[:, :], b1[:], i8), cache=True)
def _propagate_above(seg, lazy, i):
    'Propagates a segment above a given index

    Args:
        seg (np.array): The segment to propagate.
        lazy (np.array): The lazy array.
        i (int): The index to propagate above.
    '
    H = 0
    while ((1 << H) <= i):
        H += 1
    for h in range((H - 1), 0, (- 1)):
        _propagate_at(seg, lazy, (i >> h))

@njit((i8[:, :], b1[:], i8), cache=True)
def _recalc_above(seg, lazy, i):
    'Recalculates a segment above a given index

    Args:
        seg (np.array): The segment to recalculate.
        lazy (np.array): The lazy array.
        i (int): The index to recalculate above.
    '
    while (i > 1):
        i >>= 1
        seg[i] = seg_f(_eval_at(seg, lazy, (i << 1)), _eval_at(seg, lazy, ((i << 1) | 1)))

@njit((i8[:, :], b1[:], i8, i8), cache=True)
def set_val(seg, lazy, i, x):
    'Sets a value in a segment

    Args:
        seg (np.array): The segment to set the value in.
        lazy (np.array): The lazy array.
        i (int): The index to set the value at.
        x (int): The value to set