
import os
import cmath
import math
import sys
if os.getenv('LOCAL'):
    sys.stdin = open('_in.txt', 'r')
sys.setrecursionlimit((10 ** 9))
INF = float('inf')
IINF = (10 ** 18)
MOD = ((10 ** 9) + 7)

class Point():
    '\n    2次元空間上の点\n    '
    CCW_COUNTER_CLOCKWISE = 1
    CCW_CLOCKWISE = (- 1)
    CCW_ONLINE_BACK = 2
    CCW_ONLINE_FRONT = (- 2)
    CCW_ON_SEGMENT = 0

    def __init__(self, x: float, y: float):
        self.c = complex(x, y)

    @property
    def x(self):
        return self.c.real

    @property
    def y(self):
        return self.c.imag

    @staticmethod
    def from_complex(c: complex):
        return Point(c.real, c.imag)

    @staticmethod
    def from_polar(r: float, phi: float):
        c = cmath.rect(r, phi)
        return Point(c.real, c.imag)

    def __add__(self, p):
        '\n        :param Point p:\n        '
        c = (self.c + p.c)
        return Point(c.real, c.imag)

    def __iadd__(self, p):
        '\n        :param Point p:\n        '
        self.c += p.c
        return self

    def __sub__(self, p):
        '\n        :param Point p:\n        '
        c = (self.c - p.c)
        return Point(c.real, c.imag)

    def __isub__(self, p):
        '\n        :param Point p:\n        '
        self.c -= p.c
        return self

    def __mul__(self, f: float):
        c = (self.c * f)
        return Point(c.real, c.imag)

    def __imul__(self, f: float):
        self.c *= f
        return self

    def __truediv__(self, f: float):
        c = (self.c / f)
        return Point(c.real, c.imag)

    def __itruediv__(self, f: float):
        self.c /= f
        return self

    def __repr__(self):
        return '({}, {})'.format(round(self.x, 10), round(self.y, 10))

    def __neg__(self):
        c = (- self.c)
        return Point(c.real, c.imag)

    def __eq__(self, p):
        return (abs((self.c - p.c)) < EPS)

    def __abs__(self):
        return abs(self.c)

    def __lt__(self, p):
        return (((self.x - p.x) < (- EPS)) or (((self.x - p.x) < EPS) and ((self.y - p.y) < (- EPS))))

    def __le__(self, p):
        return (((self.x - p.x) < (- EPS)) or (((self.x - p.x) < EPS) and ((self.y - p.y) < EPS)))

    def __gt__(self, p):
        return (((self.x - p.x) > EPS) or (((self.x - p.x) > (- EPS)) and ((self.y - p.y) > EPS)))

    def __ge__(self, p):
        return (((self.x - p.x) > EPS) or (((self.x - p.x) > (- EPS)) and ((self.y - p.y) > (- EPS))))

    @staticmethod
    def ccw(a, b, c):
        '\n        線分 ab に対する c の位置\n        線分上にあるか判定するだけなら on_segment とかのが速い\n        Verify: http://judge.u-aizu.ac.jp/onlinejudge/description.jsp?id=CGL_1_C&lang=ja\n        :param Point a:\n        :param Point b:\n        :param Point c:\n        '
        b = (b - a)
        c = (c - a)
        det = b.det(c)
        if (det > EPS):
            return Point.CCW_COUNTER_CLOCKWISE
        if (det < (- EPS)):
            return Point.CCW_CLOCKWISE
        if (b.dot(c) < (- EPS)):
            return Point.CCW_ONLINE_BACK
        if (b.dot((b - c)) < (- EPS)):
            return Point.CCW_ONLINE_FRONT
        return Point.CCW_ON_SEGMENT

    def dot(self, p):
        '\n        内積\n        :param Point p:\n        :rtype: float\n        '
        return ((self.x * p.x) + (self.y * p.y))

    def det(self, p):
        '\n        外積\n        :param Point p:\n        :rtype: float\n        '
        return ((self.x * p.y) - (self.y * p.x))

    def dist(self, p):
        '\n        距離\n        :param Point p:\n        :rtype: float\n        '
        return abs((self.c - p.c))

    def norm(self):
        '\n        原点からの距離\n        :rtype: float\n        '
        return abs(self.c)

    def phase(self):
        '\n        原点からの角度\n        :rtype: float\n        '
        return cmath.phase(self.c)

    def angle(self, p, q):
        '\n        p に向いてる状態から q まで反時計回りに回転するときの角度\n        -pi <= ret <= pi\n        :param Point p:\n        :param Point q:\n        :rtype: float\n        '
        return ((((cmath.phase((q.c - self.c)) - cmath.phase((p.c - self.c))) + PI) % TAU) - PI)

    def area(self, p, q):
        '\n        p, q となす三角形の面積\n        :param Point p:\n        :param Point q:\n        :rtype: float\n        '
        return abs(((p - self).det((q - self)) / 2))

    def projection_point(self, p, q, allow_outer=False):
        '\n        線分 pq を通る直線上に垂線をおろしたときの足の座標\n        Verify: http://judge.u-aizu.ac.jp/onlinejudge/description.jsp?id=CGL_1_A&lang=ja\n        :param Point p:\n        :param Point q:\n        :param allow_outer: 答えが線分の間になくても OK\n        :rtype: Point|None\n        '
        diff_q = (q - p)
        r = ((self - p).dot(diff_q) / abs(diff_q))
        phase = diff_q.phase()
        ret = (Point.from_polar(r, phase) + p)
        if (allow_outer or ((p - ret).dot((q - ret)) < EPS)):
            return ret
        return None

    def reflection_point(self, p, q):
        '\n        直線 pq を挟んで反対にある点\n        Verify: http://judge.u-aizu.ac.jp/onlinejudge/description.jsp?id=CGL_1_B&lang=ja\n        :param Point p:\n        :param Point q:\n        :rtype: Point\n        '
        r = abs((self - p))
        angle = p.angle(q, self)
        angle = ((q - p).phase() - angle)
        return (Point.from_polar(r, angle) + p)

    def on_segment(self, p, q, allow_side=True):
        '\n        点が線分 pq の上に乗っているか\n        Verify: http://judge.u-aizu.ac.jp/onlinejudge/description.jsp?id=CGL_1_C&lang=ja\n        :param Point p:\n        :param Point q:\n        :param allow_side: 端っこでギリギリ触れているのを許容するか\n        :rtype: bool\n        '
        if ((not allow_side) and ((self == p) or (self == q))):
            return False
        return ((abs((p - self).det((q - self))) < EPS) and ((p - self).dot((q - self)) < EPS))

    @staticmethod
    def circumcenter_of(p1, p2, p3):
        '\n        外心\n        :param Point p1:\n        :param Point p2:\n        :param Point p3:\n        :rtype: Point|None\n        '
        if (abs((p2 - p1).det((p3 - p1))) < EPS):
            return None
        a = (((p2.x - p3.x) ** 2) + ((p2.y - p3.y) ** 2))
        b = (((p3.x - p1.x) ** 2) + ((p3.y - p1.y) ** 2))
        c = (((p1.x - p2.x) ** 2) + ((p1.y - p2.y) ** 2))
        num = ((((p1 * a) * ((b + c) - a)) + ((p2 * b) * ((c + a) - b))) + ((p3 * c) * ((a + b) - c)))
        den = (((a * ((b + c) - a)) + (b * ((c + a) - b))) + (c * ((a + b) - c)))
        return (num / den)

    @staticmethod
    def incenter_of(p1, p2, p3):
        '\n        内心\n        :param Point p1:\n        :param Point p2:\n        :param Point p3:\n        '
        d1 = p2.dist(p3)
        d2 = p3.dist(p1)
        d3 = p1.dist(p2)
        return ((((p1 * d1) + (p2 * d2)) + (p3 * d3)) / ((d1 + d2) + d3))
(A, B, H, M) = list(map(int, sys.stdin.buffer.readline().split()))
h = Point.from_polar(A, ((((H / 12) + ((M / 60) / 12)) * math.pi) * 2))
m = Point.from_polar(B, (((M / 60) * math.pi) * 2))
print(h.dist(m))
