# File changed

import math
import random

class Prime():
    seed_primes = [2, 3, 5, 7, 11, 13, 17, 19, 23, 29, 31, 37, 41, 47, 53, 59, 61, 67, 71, 73, 79, 83, 89, 97]

    def is_prime(self, n):
        'Checks if a number is prime

        Args:
            n (int): The number to check

        Returns:
            bool: True if the number is prime, False otherwise
        '
        is_prime_common = self.is_prime_common(n)
        if (is_prime_common is not None):
            return is_prime_common
        if (n < 2000000):
            return self.is_prime_bf(n)
        else:
            return self.is_prime_mr(n)

    def is_prime_common(self, n):
        'Checks if a number is prime using a common method

        Args:
            n (int): The number to check

        Returns:
            bool: True if the number is prime, False otherwise
        '
        if (n == 1):
            return False
        if (n in Prime.seed_primes):
            return True
        if any(map((lambda x: ((n % x) == 0)), self.seed_primes)):
            return False

    def is_prime_bf(self, n):
        'Checks if a number is prime using a brute force method

        Args:
            n (int): The number to check

        Returns:
            bool: True if the number is prime, False otherwise
        '
        for k in range(2, (int(math.sqrt(n)) + 1)):
            if ((n % k) == 0):
                return False
        return True

    def is_prime_mr(self, n):
        'Checks if a number is prime using a Miller-Rabin method

        Args:
            n (int): The number to check

        Returns:
            bool: True if the number is prime, False otherwise
        '
        d = (n - 1)
        while ((d % 2) == 0):
            d //= 2
        witnesses = self.get_witnesses(n)
        for w in witnesses:
            t = d
            y = pow(w, t, n)
            while ((t != (n - 1)) and (y != 1) and (y != (n - 1))):
                y = ((y ** 2) % n)
                t *= 2
            if ((y != (n - 1)) and ((t % 2) == 0)):
                return False
        return True

    def get_witnesses(self, num):
        'Gets the witnesses for a Miller-Rabin method

        Args:
            num (int): The number to check

        Returns:
            list: The witnesses
        '
        def _get_range(num):
            'Gets the range for the witnesses

            Args:
                num (int): The number to check

            Returns:
                int: The range
            '
            if (num < 2047):
                return 1
            if (num < 1373653):
                return 2
            if (num < 25326001):
                return 3
            if (num < 3215031751):
                return 4
            if (num < 2152302898747):
                return 5
            if (num < 3474749660383):
                return 6
            if (num < 341550071728321):
                return 7
            if (num < 38255123056546413051):
                return 9
            return 12
        return self.seed_primes[:_get_range(num)]

    def gcd(self, a, b):
        'Gets the greatest common denominator of two numbers

        Args:
            a (int): The first number
            b (int): The second number

        Returns:
            int: The greatest common denominator
        '
        if (a < b):
            (a, b) = (b, a)
        while (0 < b):
            (a, b) = (b, (a % b))
        return a

    @staticmethod
    def f(x, n, seed):
        'Gets the F function for a Miller-Rabin method

        Args:
            x (int): The first number
            n (int): The second number
            seed (int): The seed

        Returns:
            int: The F function
        '
        p = Prime.seed_primes[(seed % len(Prime.seed_primes))]
        return (((p * x) + seed) % n)

    def find_factor(self, n, seed=1):
        'Finds a factor of a number

        Args:
            n (int): The number to check
            seed (int, optional): The seed. Defaults to 1.

        Returns:
            int: The factor
        '
        if self.is_prime(n):
            return n
        (x, y, d) = (2, 2, 1)
        count = 0
        while (d == 1):
            count += 1
            x = self.f(x, n, seed)
            y = self.f(self.f(y, n, seed), n, seed)
            d = self.gcd(abs((x - y)), n)
        if (d == n):
            return self.find_factor(n, (seed + 1))
        return self.find_factor(d)

    def find_factors(self, n):
        'Finds the factors of a number

        Args:
            n (int): The number to check

